@@ -31,7 +31,7 @@ print_bh_base(addr, empty)
 	for (i = 0; i < 32; i++) {
 		if (bhname[i] == NULL && buf[i] == 0 && empty == 0)
 			continue;
-		p = getsymstr(buf[i]);
+		p = getsymstr_func(buf[i]);
 		mprintf("%14s %4d  " FPTR "  %s\n", bhname[i]? bhname[i]: "-", i,  buf[i], p? p: "-");
 	}
 }
