@@ -81,7 +81,7 @@ print_kmem_cache(addr, sflag, full)
 		mprintf(FPTR " %5x %3x %4lx %4x %4x  ",
 			addr, cache.objsize, cache.num, cache.colour,
 			cache.colour_off, cache.colour_next);
-		mprint_str(cache.name, CACHE_NAMELEN);
+		mprintstr(cache.name, CACHE_NAMELEN);
 		mprintf("\n");
 	} else {
 		mprintf("addr: " FPTR "\n", addr);
@@ -114,7 +114,7 @@ print_kmem_cache(addr, sflag, full)
 		mprintf("  %s\n", p? p: "NULL");
 		mprintf("failures     %lx\n", cache.failures);
 		mprintf("name         \"");
-		mprint_str(cache.name, CACHE_NAMELEN);
+		mprintstr(cache.name, CACHE_NAMELEN);
 		mprintf("\"\n");
 		mprintf("next          " FPTR " " FPTR "\n",
 			cache.next.next, cache.next.prev);
@@ -179,8 +179,8 @@ search_slab(addr)
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
-			if (++cnt > 65536) {
-				mprintf("loop?\n");
+			if (++cnt > 100000) {
+				mprintf("loop? (%lx full)\n", kmaddr);
 				break;
 			}
 		}
@@ -191,8 +191,8 @@ search_slab(addr)
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
-			if (++cnt > 65536) {
-				mprintf("loop?\n");
+			if (++cnt > 100000) {
+				mprintf("loop? (%lx partial)\n", kmaddr);
 				break;
 			}
 		}
@@ -204,8 +204,8 @@ search_slab(addr)
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
-			if (++cnt > 65536) {
-				mprintf("loop?\n");
+			if (++cnt > 100000) {
+				mprintf("loop? (%lx)\n", kmaddr);
 				break;
 			}
 		}
