@@ -6,7 +6,8 @@
 
 #define __KERNEL__
 #include <linux/mm.h>
-/*#include <linux/swap.h>*/
+
+#include "printdev.h"
 
 void
 prhead_swap_info()
@@ -45,7 +46,7 @@ print_swap_info(n, full)
 	}
 	memread(addr, sizeof(si), &si, "swap_info");
 
-	print_kdev_t(si.swap_device);
+	mprint_kdev_t(si.swap_device);
 	mprintf(FPTR " " FPTR " " FPTR " ",
 		si.swap_file, si.swap_vfsmnt, si.swap_map);
 	mprintf("%4d %5x %8lx", si.prio, si.pages, si.max);
