@@ -40,6 +40,8 @@ exception_table()
 	} else if (optind + 2 == argcnt) {
 		addr = getvalue(args[optind]);
 		eaddr = getvalue(args[optind + 1]);
+	} else {
+		THROW(usage);
 	}
 
 	prhead_exception_table();
