@@ -7,6 +7,8 @@
 #define __KERNEL__
 #include <linux/device.h>
 
+#include "flags_device.h"
+
 void
 prhead_kobject()
 {
@@ -33,8 +35,13 @@ mprint_kobject(ko)
 void
 prhead_device()
 {
+#ifdef _device_has_driver_data
+	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" "SPTR" "SPTR" BUS_ID\n",
+		"ADDR", "PARENT", "BUS", "DRIVER", "DRIVER_D", "RELEASE");
+#else
 	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" DETCH "SPTR" BUS_ID\n",
 		"ADDR", "PARENT", "BUS", "DRIVER", "RELEASE");
+#endif
 }
 
 addr_t
@@ -46,16 +53,24 @@ print_device(addr, full)
 
 	memread(addr, sizeof(dev), &dev, "device");
 	mprintf(FPTR " ", addr);
+
+#ifdef _device_has_node
 #define IS_LISTED(list) ((addr_t)dev.list.next != addr + OFFSET(struct device,list))
 	mprintf("%c%c%c%c ",
 		IS_LISTED(node)       ? 'N': '-',
 		IS_LISTED(bus_list)   ? 'B': '-',
 		IS_LISTED(driver_list)? 'D': '-',
 		IS_LISTED(children)   ? 'C': '-');
+#endif
+
 	mprintf(FPTR " ", dev.parent);
 	mprintf(FPTR " ", dev.bus);
 	mprintf(FPTR " ", dev.driver);
+#ifdef _device_has_driver_data
+	mprintf(FPTR " ", dev.driver_data);
+#else
 	mprintf("%5x ", dev.detach_state);
+#endif
 	mprintf(FPTR " ", dev.release);
 	mprintstr(dev.bus_id, sizeof(dev.bus_id));
 	mprintf("\n");
@@ -63,5 +78,9 @@ print_device(addr, full)
 		prhead_kobject();
 		mprint_kobject(&dev.kobj);
 	}
+#ifdef _device_has_node
 	return (addr_t)dev.node.next;
+#else
+	return 0;
+#endif
 }
