@@ -92,7 +92,7 @@ print_dentry(addr, sw, subdir, parent)
 void
 prhead_file()
 {
-	mprintf(SPTR" "SPTR" "SPTR" MOD       POS CNT   UID   GID ERR "SPTR" FLAGS\n",
+	mprintf(SPTR" "SPTR" "SPTR" MOD       POS CNT   UID   GID "SPTR" FLAGS\n",
 		"ADDR", "DENTRY", "F_OP", "PRIVATE");
 }
 
@@ -123,7 +123,7 @@ print_file(addr, full)
 	case 3: mprintf("rw");	break;
 	default:mprintf(" ?");	break;
 	}
-	mprintf(" %10Lx %3x %5d %5d %3d", f.f_pos, ATOMIC_READ(f.f_count), f.f_uid, f.f_gid, f.f_error);
+	mprintf(" %10Lx %3x %5d %5d", f.f_pos, ATOMIC_READ(f.f_count), f.f_uid, f.f_gid);
 	mprintf(" " FPTR, f.private_data);
 	mprintbit(fflags, f.f_flags & ~3);
 	mprintf("\n");
@@ -442,8 +442,13 @@ print_address_space(addr, plist)
 		{ 0,			NULL }
 	};
 
-	mprintf("ADDR:         " FPTR "\n", addr);
+	mprintf("ADDR:           " FPTR "\n", addr);
 	memread(addr, sizeof(as), &as, "address_space");
+	mprintf("host:           " FPTR "\n", as.host);
+
+	mprintf("page_tree:      %x, " FPTR ", ", as.page_tree.height,
+		as.page_tree.rnode);
+	print_gfp(as.page_tree.gfp_mask);
 
 #undef ISEMPTY
 #define ISEMPTY(list) \
@@ -485,26 +490,32 @@ print_address_space(addr, plist)
 			as.io_pages.next, as.io_pages.prev);
 #endif
 
-#ifdef _address_space_has_writeback_index
-	mprintf("writeback_index: %8lx\n", as.writeback_index);
-#endif
-
-	mprintf("nrpages:      %8lx\n", as.nrpages);
-	mprintf("ops:          " FPTR "\n", as.a_ops);
-	mprintf("host:         " FPTR "\n", as.host);
 #ifdef _address_space_has_i_mmap_writable	/* >= 2.6.7 */
-	mprintf("mmap:         " FPTR "  %x\n", as.i_mmap.prio_tree_node,
+	mprintf("mmap_writable:  %x\n", as.i_mmap_writable);
+	mprintf("mmap:           " FPTR "  %x\n", as.i_mmap.prio_tree_node,
 				as.i_mmap.index_bits);
-	mprintf("mmap_writable:%x\n", as.i_mmap_writable);
-	mprintf("mmap_nonlinear:" FPTR "\n", as.i_mmap_nonlinear.next);
+	mprintf("mmap_nonlinear: " FPTR "\n", as.i_mmap_nonlinear.next);
 #endif
+#ifdef _address_space_has_truncate_count
+	mprintf("truncate_count: %x\n", as.truncate_count);
+#endif
+	mprintf("nrpages:        %lx\n", as.nrpages);
+#ifdef _address_space_has_writeback_index
+	mprintf("writeback_index:%8lx\n", as.writeback_index);
+#endif
+	mprintf("ops:            " FPTR "\n", as.a_ops);
 #ifdef _address_space_has_i_mmap_shared		/* < 2.6.7 */
-	mprintf("mmap:         " FPTR "\n", as.i_mmap.next);
-	mprintf("mmap_shared:  " FPTR "\n", as.i_mmap_shared.next);
+#ifndef _address_space_has_i_mmap_nonlinear
+	mprintf("mmap:           " FPTR "\n", as.i_mmap.next);
+	mprintf("mmap_shared:    " FPTR "\n", as.i_mmap_shared.next);
 #endif
-	mprintf("gfp_mask:    ");
+#endif
+	mprintf("gfp_mask:      ");
 	mprintbit(asflags, as.flags & ~__GFP_BITS_MASK);
 	print_gfp(as.flags & __GFP_BITS_MASK);
+#ifdef _address_space_has_backing_dev_info
+	mprintf("backing_dev_info:" FPTR "\n", as.backing_dev_info);
+#endif
 
 #ifdef _address_space_has_clean_pages
 	if (plist & 1) {
