@@ -31,6 +31,7 @@ print_page(addr, lru)
 	int lru;
 {
 	struct page pg;
+	int n;
 
 	if (lru) {
 		addr -= OFFSET(struct page, lru);
@@ -39,19 +40,22 @@ print_page(addr, lru)
 	memread(addr, sizeof(pg), &pg, "page");
 
 #ifdef _page_has__count
-	mprintf("%3x ", ATOMIC_READ(pg._count));
+	n = ATOMIC_READ(pg._count);
 #else
-	mprintf("%3x ", ATOMIC_READ(pg.count));
+	n = ATOMIC_READ(pg.count);
 #endif /*_page_has__count*/
-	mprintf(FPTR " %7lx", pg.mapping, pg.index);
+	mprintf((n == -1)? "%3d ": "%3x ", n);
+	mprintf(FPTR " %7lx ", pg.mapping, pg.index);
 
 #ifdef _page_has__mapcount
-	mprintf(" %4x", ATOMIC_READ(pg._mapcount));
+	n = ATOMIC_READ(pg._mapcount);
+	mprintf((n == -1)? "%4d ": "%4x", n);
 #else
 #ifdef _page_has_mapcount
-	mprintf(" %4x", pg.mapcount);
+	n = ATOMIC_READ(pg.mapcount);
+	mprintf((n == -1)? "%4d ": "%4x", n);
 #else
-	mprintf(" " FPTR, pg.pte.direct);
+	mprintf(FPTR, pg.pte.direct);
 #endif
 #endif
 
