@@ -42,8 +42,13 @@ void
 _prhead_nfs_page(str)
 	const char *str;
 {
+#if SUBLEVEL>=9
+	mprintf(SPTR" "SPTR" "SPTR"    INDEX OFFSET BYTES COUNT\n",
+		str, "PAGE", "CONTEXT");
+#else
 	mprintf(SPTR" "SPTR" "SPTR" "SPTR" "SPTR"    INDEX OFFSET BYTES COUNT\n",
 		str, "FILE", "INODE", "CRED", "PAGE");
+#endif
 }
 
 void
@@ -61,8 +66,14 @@ print_nfs_page(addr, full)
 
 	memread(addr, sizeof(page), &page, "nfs_page");
 	mprintf(FPTR " ", addr);
-	mprintf(FPTR " " FPTR " " FPTR " " FPTR " ",
-		page.wb_file, page.wb_inode, page.wb_cred, page.wb_page);
+#if SUBLEVEL<9
+	mprintf(FPTR " " FPTR " " FPTR " ",
+		page.wb_file, page.wb_inode, page.wb_cred);
+#endif
+	mprintf(FPTR " ", page.wb_page);
+#if SUBLEVEL>=9
+	mprintf(FPTR " ", page.wb_context);
+#endif
 	mprintf("%8lx %6x %5x %5x",
 		page.wb_index, page.wb_offset, page.wb_bytes, page.wb_count);
 	mprintf("\n");
@@ -111,10 +122,17 @@ print_nfs_inode(addr, full, iflag)
 		mprintf("cache_access.jiffies   %lx\n", ni.cache_access.jiffies);
 		mprintf("cache_access.cred      "FPTR"\n", ni.cache_access.cred);
 		mprintf("cache_access.mask      %x\n", ni.cache_access.mask);
+#ifdef _nfs_inode_has_err
 		mprintf("cache_access.err       %x\n", ni.cache_access.err);
+#endif
 		mprintf("cookieverf             %x  %x\n",
 					ni.cookieverf[0], ni.cookieverf[1]);
+#ifdef _nfs_inode_has_open_files
+		mprintf("open_files             " FPTR " " FPTR "\n",
+					ni.open_files.next, ni.open_files.prev);
+#else
 		mprintf("mm_cred                " FPTR "\n", ni.mm_cred);
+#endif
 	}
 
 	return (addr_t)ni.dirty.next - OFFSET(struct nfs_inode, dirty);
