@@ -12,6 +12,7 @@
 addr_t print_radix_tree_node(addr)
 	addr_t addr;
 {
+#ifndef NO_SUCH_FILE
 	struct radix_tree_node node;
 	int i;
 
@@ -23,5 +24,6 @@ addr_t print_radix_tree_node(addr)
 		mprintf(" " FPTR, node.slots[i]);
 	}
 	mprintf("\n");
+#endif /*NO_SUCH_FILE*/
 	return 0;
 }
