@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -11,6 +11,7 @@
 #include "stacksize.h"
 #include "flags_sched.h"
 #include "flags_signal.h"
+#include "flags_file.h"
 
 extern void prhead_vm_area_struct();
 extern addr_t print_vm_area_struct();
@@ -35,7 +36,20 @@ print_files_struct(addr)
 
 	mprintf("   " FPTR " ", addr);
 	memread(addr, sizeof(files), &files, "files_struct");
-	mprintf("%3x %5d %5d %5d", ATOMIC_READ(files.count), files.max_fds, files.max_fdset, files.next_fd);
+	mprintf("%3x ", ATOMIC_READ(files.count));
+#ifdef _files_struct_has_fdtab
+	mprintf("%5d %5d %5d", files.fdtab.max_fds, files.fdtab.max_fdset, files.fdtab.next_fd);
+	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fdtab.fd, files.fdtab.close_on_exec, files.fdtab.open_fds);
+	if ((addr_t)files.fdtab.fd == addr + OFFSET(struct files_struct, fd_array))
+		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
+	else
+		memread((addr_t)files.fdtab.fd, sizeof(fds), &fds, "file");
+	if ((addr_t)files.fdtab.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
+		cfd = files.close_on_exec_init;
+	else
+		memread((addr_t)files.fdtab.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
+#else /*_files_struct_has_fdtab*/
+	mprintf("%5d %5d %5d", files.max_fds, files.max_fdset, files.next_fd);
 	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fd, files.close_on_exec, files.open_fds);
 	if ((addr_t)files.fd == addr + OFFSET(struct files_struct, fd_array))
 		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
@@ -45,9 +59,15 @@ print_files_struct(addr)
 		cfd = files.close_on_exec_init;
 	else
 		memread((addr_t)files.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
+#endif /*_files_struct_has_fdtab*/
 
 	cnt = 0;
-	for (i = 0; i < LENGTHOF(fds) && i < files.max_fds; i++) {
+#ifdef _files_struct_has_fdtab
+	for (i = 0; i < LENGTHOF(fds) && i < files.fdtab.max_fds; i++)
+#else
+	for (i = 0; i < LENGTHOF(fds) && i < files.max_fds; i++)
+#endif /*_files_struct_has_fdtab*/
+	{
 		if (fds[i]) {
 			if (cnt * (sizeof(addr_t) + 3) > 30) {
 				cnt = 0;
