@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -12,6 +12,7 @@
 #include <linux/rcupdate.h>
 #endif
 #include "slab.h"
+#include "flags_slab.h"
 
 addr_t print_slab();
 addr_t print_kmem_cache();
@@ -148,10 +149,15 @@ print_kmem_cache(addr, sflag, full, next)
 
 	} else {
 		mprintf("addr: " FPTR "\n", addr);
+#ifdef _kmem_cache_s_has_array
+		mprintf("array[0]      " FPTR "\n", cache.array[0]);
+#endif
 		mprintf("objsize      %x\n", cache.objsize);
 		mprintf("flags        %x\n", cache.flags);
 		mprintf("num          %x\n", cache.num);
+#ifdef _kmem_cache_s_has_free_limit
 		mprintf("free_limit   %x\n", cache.free_limit);
+#endif
 		mprintf("gfporder     %x\n", cache.gfporder);
 		mprintf("gfpflags     %x\n", cache.gfpflags);
 		mprintf("colour       %lx\n", cache.colour);
@@ -171,7 +177,16 @@ print_kmem_cache(addr, sflag, full, next)
 	}
 
 	if (sflag) {
+#ifdef _kmem_cache_s_has_nodelists
+		int i;
+		for (i = 0; i < MAX_NUMNODES; i++) {
+			print_kmem_list3(cache.nodelists[i], cache.num);
+		}
+#else
+#ifdef _kmem_cache_s_has_lists
 		print_kmem_list3(addr + OFFSET(kmem_cache_t, lists), cache.num);
+#endif
+#endif
 	}
 	if (next) {
 		return (addr_t)cache.next.next;
@@ -199,6 +214,10 @@ search_slab(addr)
 		len = cache.objsize * cache.num;
 		cnt = 0;
 
+#ifdef _kmem_cache_s_has_nodelists
+#warning "not implimented"
+
+#else /*_kmem_cache_s_has_nodelists*/
 		saddr = (addr_t)cache.lists.slabs_full.next - OFFSET(struct slab, list);
 		while (saddr && saddr != kmaddr - OFFSET(kmem_cache_t, next) + OFFSET(kmem_cache_t, lists.slabs_full)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
@@ -223,6 +242,7 @@ search_slab(addr)
 				break;
 			}
 		}
+#endif /*_kmem_cache_s_has_nodelists*/
 		kmaddr = (addr_t)cache.next.next;
 	}
 
