@@ -26,6 +26,7 @@ extern const commandtable_t
 	command_operations,
 	command_page,
 	command_pglist_data,
+	command_radix_tree_node,
 	command_request_queue,
 	command_rtable,
 	command_sighand_struct,
@@ -74,6 +75,7 @@ const commandtable_t *commandtable_vers[] = {
 	&command_operations,
 	&command_page,
 	&command_pglist_data,
+	&command_radix_tree_node,
 	&command_request_queue,
 	&command_rtable,
 	&command_sighand_struct,
