@@ -196,15 +196,19 @@ trace()
 			continue;
 		}
 		retad = *(unsigned int *)&stack[esp - stacktop];
-		if ((sym = searchsym_byaddr(retad)) == NULL ||
+		if (retad < kmem_low ||
+		    (sym = searchsym_byaddr(retad)) == NULL ||
 		    retad - sym->addr > 0x10000 ||
 		    (sym->addr <= retad && sym->addr + 1 >= retad)) {
 			/* maybe stack analyze fail, do RECOVERY code */
 			/* save the pointers */
 			int esp_save = esp, retad_save = retad;
 			/* search the next function from stack */
+			sym = NULL;
 			while (esp++, INTHESTACK(esp)) {
 				retad = *(unsigned int *)&stack[esp - stacktop];
+				if (retad < kmem_low)
+					continue;
 				if ((sym = searchsym_byaddr(retad)) != NULL &&
 				    (sym->type == 'T' || sym->type == 't' || sym->type == 0))
 					break;	/*found*/
@@ -216,7 +220,7 @@ trace()
 				retad = retad_save;
 				sym = searchsym_byaddr(retad);
 				mprintf(")\n");
-				continue;
+				break;
 			}
 			mprintf("?");
 		}
@@ -242,6 +246,9 @@ trace()
 				if (argsize == 0 && i < sizeof(funchead) - 3 && funchead[i + 3] != 0xc3)
 					argsize = (signed char)funchead[i + 2];
 				break;
+			/* ret */
+			} else if (c == 0xc3 || c == 0x5d && funchead[i + 1] == 0xc3) {
+				break;
 			/* push */
 			} else if (ISPUSH(c) || c == 0x6a || c == 0x9c) {
 				break;
