@@ -39,6 +39,7 @@ print_xfs_mount(addr, flag)
 {
 	xfs_mount_t m;
 	char name[32];
+	int i;
 #if 0
 	static const struct bitname mflags[] = {
 		{ XFS_MOUNT_WSYNC,		"wsync" },
@@ -95,6 +96,13 @@ print_xfs_mount(addr, flag)
 	mprintf("sb.ifree       %llx\n", m.m_sb.sb_ifree);
 	mprintf("sb.fdblocks    %llx\n", m.m_sb.sb_fdblocks);
 	mprintf("sb.frextents   %llx\n", m.m_sb.sb_frextents);
+	mprintf("sb.uuid      ");
+	for (i = 0; i < sizeof(m.m_sb.sb_uuid); i++) {
+		mprintf("%02x", *((unsigned char *)&m.m_sb.sb_uuid + i));
+	}
+	mprintf("\n");
+	mprintf("sb.uquotino    %lx\n",  m.m_sb.sb_uquotino);
+	mprintf("sb.gquotino    %lx\n",  m.m_sb.sb_gquotino);
 	mprintf("sb_bp        " FPTR "  (page_buf)\n", m.m_sb_bp);
 	mprintf("fsname       " FPTR "  \"", m.m_fsname);
 	memread((addr_t)m.m_fsname, sizeof(name), name, "xfs_mount.m_fsname");
