@@ -276,23 +276,40 @@ print_xfs_trans(addr, aflag)
 	mprintf("flags:        %x  ", trans.t_flags);
 	mprintbit(tflags, trans.t_flags);
 	mprintf("\n");
-	mprintf("icount_delta:        %lx\n", trans.t_icount_delta);
-	mprintf("ifree_delta:         %lx\n", trans.t_ifree_delta);
-	mprintf("fdblocks_delta:      %lx\n", trans.t_fdblocks_delta);
-	mprintf("res_fdblocks_delta:  %lx\n", trans.t_res_fdblocks_delta);
-	mprintf("frextents_delta:     %lx\n", trans.t_frextents_delta);
-	mprintf("res_frextents_delta: %lx\n", trans.t_res_frextents_delta);
-	mprintf("ag_freeblks_delta    %lx\n", trans.t_ag_freeblks_delta);
-	mprintf("ag_flist_delta:      %lx\n", trans.t_ag_flist_delta);
-	mprintf("ag_btree_delta:      %lx\n", trans.t_ag_btree_delta);
-	mprintf("dblocks_delta:       %lx\n", trans.t_dblocks_delta);
-	mprintf("agcount_delta:       %lx\n", trans.t_agcount_delta);
-	mprintf("imaxpct_delta:       %lx\n", trans.t_imaxpct_delta);
-	mprintf("rextsize_delta:      %lx\n", trans.t_rextsize_delta);
-	mprintf("rbmblocks_delta:     %lx\n", trans.t_rbmblocks_delta);
-	mprintf("rblocks_delta:       %lx\n", trans.t_rblocks_delta);
-	mprintf("rextents_delta:      %lx\n", trans.t_rextents_delta);
-	mprintf("rextslog_delta:      %lx\n", trans.t_rextslog_delta);
+	if (trans.t_icount_delta)
+		mprintf("icount_delta:        %lx\n", trans.t_icount_delta);
+	if (trans.t_ifree_delta)
+		mprintf("ifree_delta:         %lx\n", trans.t_ifree_delta);
+	if (trans.t_fdblocks_delta)
+		mprintf("fdblocks_delta:      %lx\n", trans.t_fdblocks_delta);
+	if (trans.t_res_fdblocks_delta)
+		mprintf("res_fdblocks_delta:  %lx\n", trans.t_res_fdblocks_delta);
+	if (trans.t_frextents_delta)
+		mprintf("frextents_delta:     %lx\n", trans.t_frextents_delta);
+	if (trans.t_res_frextents_delta)
+		mprintf("res_frextents_delta: %lx\n", trans.t_res_frextents_delta);
+	if (trans.t_ag_freeblks_delta)
+		mprintf("ag_freeblks_delta    %lx\n", trans.t_ag_freeblks_delta);
+	if (trans.t_ag_flist_delta)
+		mprintf("ag_flist_delta:      %lx\n", trans.t_ag_flist_delta);
+	if (trans.t_ag_btree_delta)
+		mprintf("ag_btree_delta:      %lx\n", trans.t_ag_btree_delta);
+	if (trans.t_dblocks_delta)
+		mprintf("dblocks_delta:       %lx\n", trans.t_dblocks_delta);
+	if (trans.t_agcount_delta)
+		mprintf("agcount_delta:       %lx\n", trans.t_agcount_delta);
+	if (trans.t_imaxpct_delta)
+		mprintf("imaxpct_delta:       %lx\n", trans.t_imaxpct_delta);
+	if (trans.t_rextsize_delta)
+		mprintf("rextsize_delta:      %lx\n", trans.t_rextsize_delta);
+	if (trans.t_rbmblocks_delta)
+		mprintf("rbmblocks_delta:     %lx\n", trans.t_rbmblocks_delta);
+	if (trans.t_rblocks_delta)
+		mprintf("rblocks_delta:       %lx\n", trans.t_rblocks_delta);
+	if (trans.t_rextents_delta)
+		mprintf("rextents_delta:      %lx\n", trans.t_rextents_delta);
+	if (trans.t_rextslog_delta)
+		mprintf("rextslog_delta:      %lx\n", trans.t_rextslog_delta);
 	mprintf("items_free:          %x\n",  trans.t_items_free);
 	mprintf("items.next:   " FPTR "\n",   trans.t_items.lic_next);
 	mprintf("items.free/unused:   %x %x\n",trans.t_items.lic_free,
