@@ -2,6 +2,7 @@
 
 extern const commandtable_t
 	command_pagebuf,
+	command_xfs_alloc_arg,
 	command_xfs_bmbt_rec,
 	command_xfs_inode,
 	command_xfs_log_item,
@@ -15,6 +16,7 @@ extern const commandtable_t
 
 const commandtable_t *commandtable_xfs[] = {
 	&command_pagebuf,
+	&command_xfs_alloc_arg,
 	&command_xfs_bmbt_rec,
 	&command_xfs_inode,
 	&command_xfs_log_item,
